'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.NO_DISTRICTS_FOUND = undefined;
exports.default = getDistrictsByState;

var _getDistricts = require('./getDistricts');

var _getDistricts2 = _interopRequireDefault(_getDistricts);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var NO_DISTRICTS_FOUND = exports.NO_DISTRICTS_FOUND = 'No districts found.';

/**
 * Fetches a list of all congressional district codes
 * based on state abbreviation (ST) from github.com/unitedstates.
 * Subject to rates limits.
 * @see https://github.com/unitedstates/districts
 * @see https://developer.github.com/v3/rate_limit/
 * @param  {string} st - Postal code abbreviation for US state. Ex: AL.
 * @returns {Promise} - Resolves with an array of district IDs.
 *                      Ex: ["AL-1","AL-2",...,"AL-7"]
 */
function getDistrictsByState(st) {
    var ST = st.toUpperCase();
    return (0, _getDistricts2.default)().then(function (_ref) {
        var districts = _ref.districts;
        return districts.filter(function (district) {
            return district.indexOf(ST) === 0;
        });
    }).then(function (districts) {
        if (!districts.length) {
            return Promise.reject(new Error(NO_DISTRICTS_FOUND));
        }
        return districts;
    });
}